import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import React from 'react';
import PropTypes from 'prop-types';
import { FormModel } from './FormModel';
import { FormItemModel } from './FormItemModel';

var FormItem = function (_React$PureComponent) {
  _inherits(FormItem, _React$PureComponent);

  function FormItem(props, context) {
    _classCallCheck(this, FormItem);

    var _this = _possibleConstructorReturn(this, _React$PureComponent.call(this, props, context));

    var formModel = context.formModel,
        formItemModel = context.formItemModel;

    _this.forms = formModel.forms;
    if (formItemModel && props.asChild) {
      _this.forms = formItemModel.forms;
    }
    _this.formItemModel = _this.forms.add(props, !!props.asList);
    _this.formModel = formModel;
    return _this;
  }

  FormItem.prototype.getChildContext = function getChildContext() {
    return { formItemModel: this.formItemModel };
  };

  FormItem.prototype.componentDidMount = function componentDidMount() {
    if (this.formModel.initialized) {
      this.formModel.validate();
    }
  };

  FormItem.prototype.componentWillUnmount = function componentWillUnmount() {
    this.forms.remove(this.formItemModel);
    if (this.formModel.initialized) {
      this.formModel.validate();
    }
  };

  FormItem.prototype.render = function render() {
    var children = this.props.children;

    return React.createElement(
      'div',
      null,
      children
    );
  };

  return FormItem;
}(React.PureComponent);

FormItem.propTypes = {
  name: PropTypes.string.isRequired,
  validator: PropTypes.func,
  asList: PropTypes.bool,
  asChild: PropTypes.bool,
  excluded: PropTypes.bool,
  children: PropTypes.oneOfType([PropTypes.element, PropTypes.arrayOf(PropTypes.element)]).isRequired
};
FormItem.defaultProps = {
  asList: false,
  asChild: false,
  excluded: false,
  validator: function validator() {
    return [];
  }
};
FormItem.contextTypes = {
  formModel: PropTypes.instanceOf(FormModel).isRequired,
  formItemModel: PropTypes.instanceOf(FormItemModel)
};
FormItem.childContextTypes = {
  formItemModel: PropTypes.instanceOf(FormItemModel).isRequired
};


export { FormItem };